/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;

import com.cloudbees.api.BeesClient;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.staxnet.appserver.utils.StringHelper;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:info")
public class DatabaseInfo extends DatabaseBase {
    private Boolean password;

    public DatabaseInfo() {
    }

    public void setPassword(Boolean password) {
        this.password = password;
    }

    @Override
    protected boolean preParseCommandLine() {
        // add the Options
        addOption( "p", "password", false, "print the database password info" );

        return true;
    }

    @Override
    protected boolean execute() throws Exception {
        String dbId = getDatabaseName();
        BeesClient client = getBeesClient(BeesClient.class, dbId);
        boolean fetchPassword = password == null ? false : true;
        com.cloudbees.api.DatabaseInfo res = client.databaseInfo(dbId, fetchPassword);

        if (isTextOutput()) {
            System.out.println( "Database name: " + res.getName());
            System.out.println( "Account:       " + res.getOwner());
            System.out.println( "Created:       " + res.getCreated());
            System.out.println( "Status:        " + res.getStatus());
            System.out.println( "Master:        " + res.getMaster() + ":" + res.getPort());
            if (res.getSlaves() != null && res.getSlaves().length > 0)
                System.out.println( "Slaves:        " + StringHelper.join(res.getSlaves(), ","));
            System.out.println( "Port:          " + res.getPort());
            System.out.println( "Username:      " + res.getUsername());
            if (fetchPassword)
                System.out.println( "Password:      " + res.getPassword());
        } else
            printOutput(res, com.cloudbees.api.DatabaseInfo.class);

        return true;
    }
}
