/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;


import com.cloudbees.api.BeesClient;
import com.cloudbees.api.DatabaseListResponse;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.cloudbees.sdk.commands.Command;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:list")
public class DatabaseList extends Command {
    private String account;

    public DatabaseList() {
    }

    @Override
    protected boolean preParseCommandLine() {
        addOption( "a", "account", true, "Account Name" );
        return true;
    }

    @Override
    protected boolean postParseCommandLine() {
        return true;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    @Override
    protected boolean execute() throws Exception {
        BeesClient client = getBeesClient(BeesClient.class);
        DatabaseListResponse res = client.databaseList(getAccount());

        if (isTextOutput()) {
            System.out.println("Databases:");
            for (com.cloudbees.api.DatabaseInfo applicationInfo: res.getDatabases()) {
                System.out.println(applicationInfo.getOwner() + "/" + applicationInfo.getName());
            }
        } else
            printOutput(res, DatabaseListResponse.class, DatabaseInfo.class);

        return true;
    }


}
