/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;

import com.cloudbees.api.BeesClient;
import com.cloudbees.api.DatabaseSnapshotDeleteResponse;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.cloudbees.sdk.utils.Helper;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:snapshot:delete")
public class DatabaseSnapshotDelete extends DatabaseBase {
    private Boolean force;
    private String snapshot;

    public DatabaseSnapshotDelete() {
        setArgumentExpected(2);
    }

    public void setForce(Boolean force) {
        this.force = force;
    }

    public String getSnapshot() {
        return snapshot;
    }

    public void setSnapshot(String snapshot) {
        this.snapshot = snapshot;
    }

    @Override
    protected String getUsageMessage() {
        return "DATABASE_NAME SNAPSHOT_ID";
    }

    @Override
    protected boolean postParseCheck() {
        if (super.postParseCheck()) {
            setSnapshot(getParameters().get(1));
            return true;
        }
        return false;
    }

    @Override
    protected boolean preParseCommandLine() {
        // add the Options
        addOption( "f", "force", false, "force delete without prompting" );

        return true;
    }

    @Override
    protected boolean execute() throws Exception {
        if (force == null || !force.booleanValue()) {
            if (!Helper.promptMatches("Are you sure you want to delete snapshot [" + getSnapshot() + "] for database [" + getDatabaseName() + "]: (y/n) ", "[yY].*")) {
                return true;
            }
        }

        BeesClient client = getBeesClient(BeesClient.class);
        DatabaseSnapshotDeleteResponse res = client.databaseSnapshotDelete(getDatabaseName(), getSnapshot());

        if (isTextOutput()) {
            if(res.isDeleted())
                System.out.println("database snapshot deleted - " + getSnapshot());
            else
                System.out.println("database snapshot could not be deleted");
        } else
            printOutput(res, DatabaseSnapshotDeleteResponse.class);

        return true;
    }

}
